@@ -1,4 +1,4 @@
-# Copyright (C) 2015-2021 by Vd.
+# Copyright (C) 2015-2022 by Vd.
 # This file is part of Rocketgram, the modern Telegram bot framework.
 # Rocketgram is released under the MIT License (see LICENSE).
 
@@ -13,3 +13,5 @@ class ChatType(EnumAutoName):
     group = auto()
     supergroup = auto()
     channel = auto()
+    sender = auto()
+    unknown = auto()
