@@ -1,4 +1,4 @@
-# Copyright (C) 2015-2021 by Vd.
+# Copyright (C) 2015-2022 by Vd.
 # This file is part of Rocketgram, the modern Telegram bot framework.
 # Rocketgram is released under the MIT License (see LICENSE).
 
@@ -34,7 +34,10 @@ class InlineQuery:
         if data is None:
             return None
 
-        chat_type = ChatType(data['chat_type']) if 'chat_type' in data else None
+        try:
+            chat_type = ChatType(data['chat_type'])
+        except (ValueError, KeyError):
+            chat_type = ChatType.unknown
 
         return cls(data['id'], User.parse(data['from']), Location.parse(data.get('location')),
                    data['query'], data['offset'], chat_type)
