@@ -1,4 +1,4 @@
-# Copyright (C) 2015-2021 by Vd.
+# Copyright (C) 2015-2022 by Vd.
 # This file is part of Rocketgram, the modern Telegram bot framework.
 # Rocketgram is released under the MIT License (see LICENSE).
 
@@ -33,7 +33,7 @@ current_user = ContextVar('current_user')
 
 class Context:
     __instance: 'Context' = None
-    __slots__ = tuple()
+    __slots__ = ()
 
     def __new__(cls):
         if Context.__instance is None:
@@ -273,4 +273,4 @@ class Context:
             self.user = update.chat_member.user
 
 
-context = Context.instance()
+context: Context = Context.instance()
