@@ -1,4 +1,4 @@
-# Copyright (C) 2015-2021 by Vd.
+# Copyright (C) 2015-2022 by Vd.
 # This file is part of Rocketgram, the modern Telegram bot framework.
 # Rocketgram is released under the MIT License (see LICENSE).
 
@@ -6,20 +6,20 @@
 from dataclasses import replace
 
 from .middleware import EmptyMiddleware
-from .. import api
+from ..api import Request
 
 
 class DefaultValuesMiddleware(EmptyMiddleware):
     __slots__ = ('__defaults',)
 
     def __init__(self, **defaults):
-        self.__defaults = defaults
+        self.__defaults = defaults.copy()
 
     @property
     def defaults(self):
         return self.__defaults.copy()
 
-    def before_request(self, request: 'api.Request') -> 'api.Request':
+    def before_request(self, request: Request) -> Request:
         replaces = dict()
 
         for k, v in self.__defaults.items():
