@@ -1,4 +1,4 @@
-﻿# Copyright (C) 2015-2021 by Vd.
+﻿# Copyright (C) 2015-2022 by Vd.
 # This file is part of Rocketgram, the modern Telegram bot framework.
 # Rocketgram is released under the MIT License (see LICENSE).
 
@@ -6,13 +6,13 @@
 import re
 
 MD_RE = re.compile(r"([*_`\[])")
-MD2_RE = re.compile(r"([_*\[\]()~`>#+\-|{}.!])")
+MD2_RE = re.compile(r"([_*\[\]()~`>#+\-=|{}.!\\])")
 
 
 def html(text: str) -> str:
     """Helper function to escape html symbols"""
 
-    return text.replace(u'&', u'&amp;').replace(u'<', u'&lt;').replace(u'>', u'&gt;')
+    return text.replace('&', '&amp;').replace('<', '&lt;').replace('>', '&gt;')
 
 
 def markdown(text: str) -> str:
